===============
Release History
===============

v0.1.93 (2021-01-7)
* compatibility fix with navis v0.5, fixing neuronlist access

v0.1.92 (2020-12-16)
* fixing dendrogram return

v0.1.8 (2020-12-11)
* upload fix 4

v0.1.7 (2020-12-11)
* upload fix 3

v0.1.6 (2020-12-11)
* upload fix 2

v0.1.5 (2020-12-11)
* upload fix

v0.1.4 (2020-12-11)
* functions in dendrogram.py, connectivity.py, morphoelectric.py, utils.py, stats.py tidied using typing module
* creating an adjacency matrix from synaptic connections expanded to function on both presynapses and postsynapses
* new function for checking whether the input is a navis neuron
* added the morphoelectric functions to create a passive electrotonic model of any neuron
* added clustering functions to find the nodes belonging to the same compartments

v0.1.3 (2020-12-3)
* interactive dendrogram fix

v0.1.2 (2020-12-3)
* node bug fixed

v0.1.1 (2020-12-3)
Fixed

* bug import

v0.1.0 (2020-12-3)
----------------------------
Fixed

* Cleared Lint
* fixed long lines
* added init files
